==> paimon-bundle-0.8.2-sources.jar: org/apache/paimon/catalog/FileSystemCatalogFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.catalog;

import org.apache.paimon.fs.FileIO;
import org.apache.paimon.fs.Path;
import org.apache.paimon.privilege.FileBasedPrivilegeManager;
import org.apache.paimon.privilege.PrivilegeManager;
import org.apache.paimon.privilege.PrivilegedCatalog;
import org.apache.paimon.table.TableType;

import static org.apache.paimon.options.CatalogOptions.TABLE_TYPE;

/** Factory to create {@link FileSystemCatalog}. */
public class FileSystemCatalogFactory implements CatalogFactory {

    public static final String IDENTIFIER = "filesystem";

    @Override
    public String identifier() {
        return IDENTIFIER;
    }

    @Override
    public Catalog create(FileIO fileIO, Path warehouse, CatalogContext context) {
        if (!TableType.MANAGED.equals(context.options().get(TABLE_TYPE))) {
            throw new IllegalArgumentException(
                    "Only managed table is supported in File system catalog.");
        }

        Catalog catalog = new FileSystemCatalog(fileIO, warehouse, context.options());

        PrivilegeManager privilegeManager =
                new FileBasedPrivilegeManager(
                        warehouse.toString(),
                        fileIO,
                        context.options().get(PrivilegedCatalog.USER),
                        context.options().get(PrivilegedCatalog.PASSWORD));
        if (privilegeManager.privilegeEnabled()) {
            catalog = new PrivilegedCatalog(catalog, privilegeManager);
        }

        return catalog;
    }
}

==> paimon-bundle-0.9.0-sources.jar: org/apache/paimon/catalog/FileSystemCatalogFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.catalog;

import org.apache.paimon.fs.FileIO;
import org.apache.paimon.fs.Path;
import org.apache.paimon.table.TableType;

import static org.apache.paimon.options.CatalogOptions.TABLE_TYPE;

/** Factory to create {@link FileSystemCatalog}. */
public class FileSystemCatalogFactory implements CatalogFactory {

    public static final String IDENTIFIER = "filesystem";

    @Override
    public String identifier() {
        return IDENTIFIER;
    }

    @Override
    public Catalog create(FileIO fileIO, Path warehouse, CatalogContext context) {
        if (!TableType.MANAGED.equals(context.options().get(TABLE_TYPE))) {
            throw new IllegalArgumentException(
                    "Only managed table is supported in File system catalog.");
        }

        return new FileSystemCatalog(fileIO, warehouse, context.options());
    }
}
